@@ -1,12 +1,10 @@
 from typing import *
-import torch
+
 import matplotlib.pyplot as plt
 import numpy as np
-from skimage.transform import resize
+import torch
 from skimage.color import gray2rgb
-from df2d.util import pwd
-import os
-from typing import *
+from skimage.transform import resize
 
 
 class Drosophila2Dataset(torch.utils.data.Dataset):
@@ -23,9 +21,6 @@ class Drosophila2Dataset(torch.utils.data.Dataset):
         self.img_size = img_size
         self.heatmap_size = heatmap_size
         self.augmentation = augmentation
-        self.m = torch.load(os.path.join(pwd(), "../weights/mean.pth.tar"))[
-            "mean"
-        ].data.numpy()[:, np.newaxis, np.newaxis]
 
     def __getitem__(self, idx):
         img_path, pts2d = self.inp[idx]
@@ -42,8 +37,6 @@ class Drosophila2Dataset(torch.utils.data.Dataset):
         # remove the mean
         img = img - 0.22
 
-        np.save("/home/user/Desktop/test2", img)
-
         return img, pts2d, tuple(self.inp[idx])
 
     def __len__(self):
